![Project Logo](https://imgs.search.brave.com/lPl-BWFfBCvh025FDErfp0uAWDvVYXzi_YjqXf3AjRM/rs:fit:860:0:0:0/g:ce/aHR0cHM6Ly9jZG5h/Lmljb25zY291dC5j/b20vaW1nL2V4Y2x1/c2l2ZS4xZTFiZTQ3/LnN2Zw)

# PowerDecos

|         | Placeholder                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
|---------| |
| Testing | [![CI - Test](https://github.com/pandas-dev/pandas/actions/workflows/unit-tests.yml/badge.svg)](https://github.com/MrCode200/power_deco/tests) [![Coverage](https://codecov.io/github/pandas-dev/pandas/coverage.svg?branch=main)](https://codecov.io/gh/pandas-dev/pandas)                                                                                                                                                                                                                                                                                                            |
| Package | [![PyPI Latest Release](https://img.shields.io/pypi/v/pandas.svg)](https://pypi.org/project/pandas/) [![PyPI Downloads](https://img.shields.io/pypi/dm/pandas.svg?label=PyPI%20downloads)](https://pypi.org/project/pandas/) [![Conda Latest Release](https://anaconda.org/conda-forge/pandas/badges/version.svg)](https://anaconda.org/conda-forge/pandas) [![Conda Downloads](https://img.shields.io/conda/dn/conda-forge/pandas.svg?label=Conda%20downloads)](https://anaconda.org/conda-forge/pandas)                                                                              |
| Meta    | [![Powered by NumFOCUS](https://img.shields.io/badge/powered%20by-NumFOCUS-orange.svg?style=flat&colorA=E1523D&colorB=007D8A)](https://numfocus.org) [![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.3509134.svg)](https://doi.org/10.5281/zenodo.3509134) [![License - BSD 3-Clause](https://img.shields.io/pypi/l/pandas.svg)](https://github.com/pandas-dev/pandas/blob/main/LICENSE) [![Slack](https://img.shields.io/badge/join_Slack-information-brightgreen.svg?logo=slack)](https://pandas.pydata.org/docs/dev/development/community.html?highlight=slack#community-slack) |



A Python package full of various decorator utilities.


### It provides:

- Powerful, Simple but useful decorators

## Table of Contents

- [Installation](#installation)
- [Testing](#testing)
- [License](LICENSE.txt)
- [Documentation](#documentation)
- [Road Map](#road-map)
- [Getting Help](#getting-help)
- [Discussion and Development](#discussion-and-development)
- [Call for Contributions](#call-for-contributions)
- [Credits](#credits)
- [Getting Help](#getting-help)

### Installation

1. Ensure you have [Python](https://www.python.org/) installed.

   ```bash
    pip install git+https://github.com/MrCode200/power_deco.git

### Testing:

PowerDecos requires `pytest`.  Tests can then be run after installation with:

    python -c "import power_decos, sys; sys.exit(power_decos.test() is False)"
    # Haven't tested if it works

## Documentation

- To view documentation in your website click [here](https://rawcdn.githack.com/MrCode200/power_deco/11d24c66d5ee9304c11eaded9f19b04a360b0bbc/docs/html/index.html).

Or

- Run [index.html](docs/html/index.html) in your browser after cloning this project


## Road Map

1. [ ] Finish Documentation


## Call for Contributions

We’re excited that you’re interested in contributing to PowerDecos! Whether you’re fixing bugs, adding new features, improving documentation, or simply suggesting enhancements, your contributions are invaluable to us.


Every bit helps, and we appreciate your effort and enthusiasm!

Please refer to our [CONTRIBUTING.md](CONTRIBUTING.md) for more details.

## Credits

- No Credits yet

## Getting Help

For any questions or support, please first read our [FAQ.md](FAQ.md)

Then contact:

- **Your Name** - [luffydmoneky19992024@gmail.com](mailto:luffydmoneky19992024@gmail.com)
- **Project Link** - [https://github.com/MrCode200/power_deco](https://github.com/MrCode200/power_deco)
